pub fn record_rollback_sub_trajectory()Expand description
Record the sub-trajectory that we expect to repetedely traverse during fuzzing soft-rollback.
pub fn record_rollback_sub_trajectory()Record the sub-trajectory that we expect to repetedely traverse during fuzzing soft-rollback.